@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.1 Maybourne
+ * LMS version 1.3.4 Terok
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: LMSDB_common.class.php,v 1.23 2004/02/18 12:49:23 lukasz Exp $
+ *  $Id: LMSDB_common.class.php,v 1.26 2004/03/14 21:41:32 lukasz Exp $
  */
 
 /*
@@ -30,25 +30,27 @@
 
 Class LMSDB_common
 {
-	var $_version="1.3.1 Maybourne";
-	var $_revision='$Revision: 1.23 $';
+	var $_version = '1.3.4 Terok';
+	var $_revision = '$Revision: 1.26 $';
 	
 	// Driver powinien nadpisa t zmienn wartoci TRUE, eby
 	// funkcja inicjujca baze danych wiedziaa e driver si poprawnie
 	// zaadowa
 	
-	var $_loaded=FALSE;
+	var $_loaded = FALSE;
 
 	// Wewntrzne zmienne bazy danych, tj, resource, link, itp.
 
-	var $_dbtype='NONE';
-	var $_dblink=NULL;
-	var $_dbhost=NULL;
-	var $_dbuser=NULL;
-	var $_dbname=NULL;
-	var $_error=NULL;
-	var $_query=NULL;
-	var $_result=NULL;
+	var $_dbtype = 'NONE';
+	var $_dblink = NULL;
+	var $_dbhost = NULL;
+	var $_dbuser = NULL;
+	var $_dbname = NULL;
+	var $_error = FALSE;
+	var $_query = NULL;
+	var $_result = NULL;
+
+	var $errors = array();
 
 	function LMSDB_common()
 	{
@@ -69,9 +71,14 @@ Class LMSDB_common
 
 	function Execute($query, $inputarray = NULL)
 	{
-		// wykonuje query sql'owe, jednoczenie je parsujc
-		$this->_driver_execute($this->_query_parser($query,$inputarray));
-		// i zwraca ilo zmodyfikowanych wierszy
+	//	echo $this->_query_parser($query,$inputarray).'<HR>';
+		if(! $this->_driver_execute($this->_query_parser($query,$inputarray)))
+		{
+			$this->errors[] = array(
+					'query' => $this->_query,
+					'error' => $this->_driver_geterror()
+					);
+		}
 		return $this->_driver_affected_rows();
 	}
 
