@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.0 Apophis
+ * LMS version 1.3.4 Terok
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,17 +21,17 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: balancenew.php,v 1.16 2004/02/18 12:49:23 lukasz Exp $
+ *  $Id: balancenew.php,v 1.19 2004/04/08 15:21:59 chilek Exp $
  */
 
-$_SESSION[backto] = $_SERVER[QUERY_STRING];
+$_SESSION['backto'] = $_SERVER['QUERY_STRING'];
 
-$layout[pagetitle]="Nowa operacja finansowa";
-$SMARTY->assign("comment",$_SESSION[addbc]);
-$SMARTY->assign("time", $_SESSION[addbt]);
-$SMARTY->assign("value", $_SESSION[addbv]);
-$SMARTY->assign("layout",$layout);
-$SMARTY->assign("users",$LMS->GetUserNames());
-$SMARTY->display("balancenew.html");
+$layout['pagetitle'] = "Nowa operacja finansowa";
+$SMARTY->assign('comment',$_SESSION['addbc']);
+$SMARTY->assign('taxvalue', $_SESSION['addbtax']);
+$SMARTY->assign('time', $_SESSION['addbt']);
+$SMARTY->assign('value', $_SESSION['addbv']);
+$SMARTY->assign('users',$LMS->GetUserNames());
+$SMARTY->display('balancenew.html');
 
 ?>
\ No newline at end of file
