@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.1 Maybourne
+ * LMS version 1.3.4 Terok
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: chooseip.php,v 1.23 2004/02/21 19:38:16 lukasz Exp $
+ *  $Id: chooseip.php,v 1.24 2004/03/11 17:24:21 lukasz Exp $
  */
 
 $p = $_GET['p'];
@@ -49,7 +49,6 @@ if($p == "main")
 
 $layout['pagetitle'] = "Wybierz adres IP";
 
-$SMARTY->assign('layout',$layout);
 $SMARTY->assign('part',$p);
 $SMARTY->assign('js',$js);
 $SMARTY->assign('networks',$networks);
