@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.1 Maybourne
+ * LMS version 1.3.4 Terok
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: choosemac.php,v 1.14 2004/02/21 19:38:16 lukasz Exp $
+ *  $Id: choosemac.php,v 1.15 2004/03/11 17:24:21 lukasz Exp $
  */
 
 $layout['pagetitle'] = "Wybierz adres MAC";
@@ -51,7 +51,6 @@ if($p == "main")
 	$SMARTY->assign('maclist',$maclist);
 }
 
-$SMARTY->assign('layout',$layout);
 $SMARTY->assign('part',$p);
 $SMARTY->assign('js',$js);
 $SMARTY->display('choosemac.html');
