@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.1 Maybourne
+ * LMS version 1.3.4 Terok
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,14 +21,13 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: dblist.php,v 1.20 2004/02/21 19:38:17 lukasz Exp $
+ *  $Id: dblist.php,v 1.21 2004/03/11 17:24:21 lukasz Exp $
  */
 
 $layout['pagetitle'] = "Bazy danych";
 
 $dblist = $LMS->DatabaseList();
 
-$SMARTY->assign('layout',$layout);
 $SMARTY->assign('dblist',$dblist);
 $SMARTY->display('header.html');
 $SMARTY->display('dblist.html');
