@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.1 Maybourne
+ * LMS version 1.3.4 Terok
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: invoicenew.php,v 1.7 2004/02/21 19:38:17 lukasz Exp $
+ *  $Id: invoicenew.php,v 1.12 2004/05/31 06:50:31 alec Exp $
  */
 
 $layout['pagetitle'] = 'Nowa faktura';
@@ -39,19 +39,24 @@ switch($_GET['action'])
 {
 	case 'additem':
 		$itemdata = r_trim($_POST);
-		foreach(array('count', 'valuenetto', 'taxvalue', 'valuebrutto') as $key)
-			$itemdata[$key] = sprintf('%01.2f',$itemdata[$key]);
+		foreach(array('count', 'valuenetto', 'valuebrutto') as $key)
+			$itemdata[$key] = sprintf('%01.2f', str_replace(',','.',$itemdata[$key]));
+		if ($itemdata['taxvalue'] != '')
+			$itemdata['taxvalue'] = sprintf('%01.2f',$itemdata['taxvalue']);
 		if($itemdata['count'] > 0 && $itemdata['name'] != '')
 		{
-			if($itemdata['taxvalue'] < 0 || $itemdata['taxvalue'] > 100)
+			$taxvalue = $itemdata['taxvalue'];
+			if ($taxvalue == '')
+				$taxvalue = 0;
+			if($taxvalue < 0 || $taxvalue > 100)
 				$error['taxvalue'] = 'Niepoprawna wysoko podatku!';
 			if($itemdata['valuenetto'] != 0)
-				$itemdata['valuebrutto'] = round($itemdata['valuenetto'] * ($itemdata['taxvalue'] / 100 + 1),2);
+				$itemdata['valuebrutto'] = round($itemdata['valuenetto'] * ($taxvalue / 100 + 1),2);
 			elseif($itemdata['valuebrutto'] != 0)
-				$itemdata['valuenetto'] = round($itemdata['valuebrutto'] / ($itemdata['taxvalue'] + 100) * 100, 2);
+				$itemdata['valuenetto'] = round($itemdata['valuebrutto'] / ($taxvalue + 100) * 100, 2);
 			$itemdata['s_valuenetto'] = $itemdata['valuenetto'] * $itemdata['count'];
 			$itemdata['s_valuebrutto'] = $itemdata['valuebrutto'] * $itemdata['count'];
-			$itemdata['posuid'] = getmicrotime();
+			$itemdata['posuid'] = (string) getmicrotime();
 			$contents[] = $itemdata;
 		}
 	break;
@@ -64,13 +69,13 @@ switch($_GET['action'])
 	case 'deletepos':
 		if(sizeof($contents))
 			foreach($contents as $idx => $row)
-				if($row['posuid'] == $_GET['posuid'])
+				if($row['posuid'] == $_GET['posuid']) 
 					unset($contents[$idx]);
 	break;
 
 	case 'setcustomer':
-		if($LMS->UserExists(($_GET['userid'] != '' ? $_GET['userid'] : $_POST['userid'])))
-			$customer = $LMS->GetUser(($_GET['userid'] != '' ? $_GET['userid'] : $_POST['userid']));
+		if($LMS->UserExists(($_GET['userid'] != '' ? $_GET['userid'] : $_POST['user'])))
+			$customer = $LMS->GetUser(($_GET['userid'] != '' ? $_GET['userid'] : $_POST['user']));
 		$invoice['paytime'] = sprintf('%d', $_POST['invoice']['paytime']);
 		$invoice['paytype'] = trim($_POST['invoice']['paytype']);
 	break;
@@ -88,7 +93,7 @@ switch($_GET['action'])
 	break;
 }
 
-if($invoice['paytime'] < 1)
+if($invoice['paytime'] < 0)
 	$invoice['paytime'] = 14;
 if($invoice['paytype'] == '')
 	$invoice['paytype'] = 'GOTWKA';
@@ -109,7 +114,6 @@ $SMARTY->assign('customer',$customer);
 $SMARTY->assign('invoice',$invoice);
 $SMARTY->assign('tariffs',$tariffs);
 $SMARTY->assign('users',$users);
-$SMARTY->assign('layout',$layout);
 $SMARTY->display('invoicenew.html');
 
 ?>
