@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.1 Maybourne
+ * LMS version 1.3.4 Terok
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: netinfo.php,v 1.26 2004/02/21 19:38:17 lukasz Exp $
+ *  $Id: netinfo.php,v 1.27 2004/03/11 17:24:22 lukasz Exp $
  */
 
 if(!$LMS->NetworkExists($_GET['id']))
@@ -39,7 +39,6 @@ $network = $LMS->GetNetworkRecord($_GET['id'],$_GET['page'],1024);
 
 $layout['pagetitle'] = "Informacja o sieci: ".$network['name'];
 
-$SMARTY->assign('layout',$layout);
 $SMARTY->assign('network',$network);
 $SMARTY->display('netinfo.html');
 
