@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.1 Maybourne
+ * LMS version 1.3.4 Terok
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: nodeadd.php,v 1.45 2004/02/23 11:49:43 lukasz Exp $
+ *  $Id: nodeadd.php,v 1.46 2004/03/11 17:24:22 lukasz Exp $
  */
 
 
@@ -129,7 +129,6 @@ $SMARTY->assign('users',$users);
 $SMARTY->assign('error',$error);
 $SMARTY->assign('userinfo',$userinfo);
 $SMARTY->assign('nodedata',$nodedata);
-$SMARTY->assign('layout',$layout);
 
 $SMARTY->display('nodeadd.html');
 
