@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3-cvs
+ * LMS version 1.3.4 Terok
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: nodeedit.php,v 1.48 2004/04/18 08:45:09 chilek Exp $
+ *  $Id: nodeedit.php,v 1.50 2004/05/16 14:09:50 alec Exp $
  */
 
 if(!$LMS->NodeExists($_GET['id']))
@@ -32,9 +32,17 @@ if(!$LMS->NodeExists($_GET['id']))
 
 if($_GET['action']=="link")
 {
-	$LMS->NetDevLinkNode($_GET['id'],$_GET['devid']);
-	header("Location: ?m=nodeinfo&id=".$_GET['id']);
-	die;
+	$netdev = $LMS->GetNetDev($_GET['devid']); 
+	if($netdev['ports'] <= $netdev['takenports'])
+	        $error['netdev'] = "Brak wolnych portw w wybranym urzdzeniu!";
+	$errorlinkdev = $netdev;
+
+	if(!$error) 
+	{
+		$LMS->NetDevLinkNode($_GET['id'],$_GET['devid']);
+		header("Location: ?m=nodeinfo&id=".$_GET['id']);
+		die;
+	}
 }
 
 $nodeid = $_GET['id'];
@@ -127,7 +135,6 @@ if(isset($nodeedit))
 	$nodeinfo['access'] = $nodeedit['access'];
 	$nodeinfo['ownerid'] = $nodeedit['ownerid'];
 
-
 	if(!$error)
 	{
 		$LMS->NodeUpdate($nodeedit);
@@ -143,7 +150,7 @@ $balancelist = $LMS->GetUserBalanceList($owner);
 $usergroups = $LMS->UsergroupGetForUser($ownerid);
 $otherusergroups = $LMS->GetGroupNamesWithoutUser($ownerid);
 
-$nodeinfo['netdev'] = $LMS->GetNetDev($nodeinfo['netdev']);
+$nodeinfo['netdev'] = $errorlinkdev ? $netdev : $LMS->GetNetDev($nodeinfo['netdev']);
 $netdevices = $LMS->GetNetDevList();
 unset($netdevices['total']);
 unset($netdevices['direction']);
