@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.1 Maybourne
+ * LMS version 1.3.4 Terok
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: paymentinfo.php,v 1.4 2004/02/21 19:38:17 lukasz Exp $
+ *  $Id: paymentinfo.php,v 1.5 2004/03/11 17:24:22 lukasz Exp $
  */
 
 if(!$LMS->PaymentExists($_GET['id']))
@@ -36,7 +36,6 @@ $layout['pagetitle'] = "Informacja o opacie staej: ".$payment['name'];
 
 $_SESSION['backto'] = $_SERVER['QUERY_STRING'];
 
-$SMARTY->assign('layout',$layout);
 $SMARTY->assign('payment',$payment);
 $SMARTY->display('paymentinfo.html');
 
