@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3-cvs
+ * LMS version 1.3.4 Terok
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: rtqueueview.php,v 1.5 2004/03/11 19:41:58 lukasz Exp $
+ *  $Id: rtqueueview.php,v 1.7 2004/07/02 11:24:52 alec Exp $
  */
 
 if(! $LMS->QueueExists($_GET['id']))
@@ -29,15 +29,24 @@ if(! $LMS->QueueExists($_GET['id']))
 	header('Location: ?m=rtqueuelist');
 	die;
 }
+
 $queuedata['id'] = $_GET['id'];
+
+if(! $LMS->GetAdminRightsRT($SESSION->id, $queuedata['id']))
+{
+	$SMARTY->display('noaccess.html');
+	die;
+}
+
 $queuedata['name'] = $LMS->GetQueueName($queuedata['id']);
 
-$layout['pagetitle'] = 'Podgld kolejki '.$queuedata['name'];
+$layout['pagetitle'] = 'Podgld kolejki: '.$queuedata['name'];
 $queue = $LMS->GetQueueContent($_GET['id']);
 
+$_SESSION['backto'] = $_SERVER['QUERY_STRING'];
+
 $SMARTY->assign('queue', $queue);
 $SMARTY->assign('queuedata', $queuedata);
 $SMARTY->display('rtqueueview.html');
-?><PRE><?
-print_r($queue);
+
 ?>
