@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3-cvs
+ * LMS version 1.3.4 Terok
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: tariffadd.php,v 1.36 2004/04/07 13:41:18 chilek Exp $
+ *  $Id: tariffadd.php,v 1.37 2004/06/19 14:56:45 alec Exp $
  */
 
 $tariffadd = $_POST['tariffadd'];
@@ -46,27 +46,43 @@ if(isset($tariffadd))
 		if(!(ereg('^[0-9.,]+$',$tariffadd['taxvalue'])) || $tariffadd['taxvalue'] < 0 || $tariffadd['taxvalue'] > 100)
 			$error['taxvalue'] = 'Podana stawka podatku jest niepoprawna!';
 
-	if(!(ereg('^[0-9]+$', $tariffadd['uprate'])) && $tariffadd['uprate'] != '')
-		$error['uprate'] = 'Pole uprate musi zawiera liczb cakowit';
 	if($tariffadd['uprate']=='') $tariffadd['uprate'] = 0;
-		
-	if(!ereg('^[0-9]+$', $tariffadd['downrate']) && $tariffadd['downrate'] != '')
-		$error['downrate'] = 'Pole downrate zawiera liczb cakowit';
 	if($tariffadd['downrate']=='') $tariffadd['downrate'] = 0;
-	
-	if(($tariffadd['uprate'] < 8 || $tariffadd['uprate'] > 4096) && $tariffadd['uprate'] != '')
-		$error['uprate'] = 'Pole uprate musi zawiera liczb z przedziau 8 - 4096';
+	if($tariffadd['upceil']=='') $tariffadd['upceil'] = 0;
+	if($tariffadd['downceil']=='') $tariffadd['downceil'] = 0;
+	if($tariffadd['climit']=='') $tariffadd['climit'] = 0;
+	if($tariffadd['plimit']=='') $tariffadd['plimit'] = 0;
+
+	if(!ereg('^[0-9]+$', $tariffadd['uprate']))
+		$error['uprate'] = 'To pole musi zawiera liczb cakowit';
+	if(!ereg('^[0-9]+$', $tariffadd['downrate']))
+		$error['downrate'] = 'To pole musi zawiera liczb cakowit';
+	if(!ereg('^[0-9]+$', $tariffadd['upceil']))
+		$error['upceil'] = 'To pole musi zawiera liczb cakowit';
+	if(!ereg('^[0-9]+$', $tariffadd['downceil']))
+		$error['downceil'] = 'To pole musi zawiera liczb cakowit';
+	if(!ereg('^[0-9]+$', $tariffadd['climit']))
+		$error['climit'] = 'To pole musi zawiera liczb cakowit';
+	if(!ereg('^[0-9]+$', $tariffadd['plimit']))
+		$error['plimit'] = 'To pole musi zawiera liczb cakowit';
+
+	if(($tariffadd['uprate'] < 8 || $tariffadd['uprate'] > 4096) && $tariffadd['uprate'] != 0)
+		$error['uprate'] = 'To pole musi zawiera liczb z przedziau 8 - 4096';
+	if(($tariffadd['downrate'] < 8 || $tariffadd['downrate'] > 4096) && $tariffadd['downrate'] != 0)
+		$error['downrate'] = 'To pole musi zawiera liczb z przedziau 8 - 4096';
+	if(($tariffadd['upceil'] < 8 || $tariffadd['upceil'] < $tariffadd['uprate']) && $tariffadd['upceil'] != 0)
+		$error['upceil'] = 'To pole musi zawiera liczb wiksz od 8 i wiksz od upload rate';
+	if(($tariffadd['downceil'] < 8 || $tariffadd['downceil'] < $tariffadd['downrate']) && $tariffadd['downceil'] != 0)
+		$error['downceil'] = 'To pole musi zawiera liczb wiksz od 8 i wiksz od download rate';
 
-	if(($tariffadd['downrate'] < 8 || $tariffadd['downrate'] > 4096) && $tariffadd['downrate'] != '')
-		$error['downrate'] = 'Pole downrate musi zawiera liczb z przedziau 8 - 4096';
-	
 	if($tariffadd['name'] == '')
 		$error['name'] = 'Musisz poda nazw taryfy!';
 	else
 		if($LMS->GetTariffIDByName($tariffadd['name']))
 			$error['name'] = "Istnieje ju taryfa o nazwie '".$tariffadd['name']."'!";
 
-	if(!$error){
+	if(!$error)
+	{
 		header('Location: ?m=tarifflist&id='.$LMS->TariffAdd($tariffadd));
 		die;
 	}
