@@ -1,6 +1,6 @@
 <?php
 
-/* LMS version 1.3-cvs
+/* LMS version 1.3.4 Terok
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -20,32 +20,39 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: traffic.php,v 1.14 2004/03/11 17:24:22 lukasz Exp $
+ *  $Id: traffic.php,v 1.16 2004/07/05 23:27:54 lukasz Exp $
  */
 
-$layout['pagetitle'] = "Statystyki wykorzystania cza";
+$layout['pagetitle'] = 'Statystyki wykorzystania cza';
 
 $bars = 1;
 
+if (isset($_GET['bar']) && isset($_POST['order']))
+	$_SESSION['trafficorder'] = $_POST['order'];
+	
 switch($_GET['bar'])
 {
-	case "hour":
-		$traffic = $LMS->Traffic( "?NOW?-(60*60)", "?NOW?", 0, "download");
+	case 'hour':
+		$traffic = $LMS->Traffic( '?NOW?-(60*60)', '?NOW?', 0,
+			isset($_SESSION['trafficorder']) ? $_SESSION['trafficorder'] : 'download');
 	break;
 
-	case "day":
-		$traffic = $LMS->Traffic( "?NOW?-(60*60*24)","?NOW?",  0, "download");
+	case 'day':
+		$traffic = $LMS->Traffic( '?NOW?-(60*60*24)','?NOW?',  0,
+			isset($_SESSION['trafficorder']) ? $_SESSION['trafficorder'] : 'download');
 	break;
 
-	case "month":
-		$traffic = $LMS->Traffic( "?NOW?-(60*60*24*30)", "?NOW?", 0, "download");
+	case 'month':
+		$traffic = $LMS->Traffic( '?NOW?-(60*60*24*30)', '?NOW?', 0,
+			isset($_SESSION['trafficorder']) ? $_SESSION['trafficorder'] : 'download');
 	break;
 
-	case "year":
-		$traffic = $LMS->Traffic( "?NOW?-(60*60*24*365)", "?NOW?", 0, "download");
+	case 'year':
+		$traffic = $LMS->Traffic( '?NOW?-(60*60*24*365)', '?NOW?', 0,
+			isset($_SESSION['trafficorder']) ? $_SESSION['trafficorder'] : 'download');
 	break;
 
-	case "user":
+	case 'user':
 		$traffic = $LMS->Traffic($_POST['from'], $_POST['to'], $_POST['net'], $_POST['order'], $_POST['limit']);
 	break;
 
@@ -61,8 +68,8 @@ $upload = $traffic['upload'];
 
 // fuck this anyway... Maybe i write function in LMS:: for this, but not now
 
-$starttime = $DB->GetOne("SELECT MIN(dt) FROM stats");
-$endtime = $DB->GetOne("SELECT MAX(dt) FROM stats");
+$starttime = $DB->GetOne('SELECT MIN(dt) FROM stats');
+$endtime = $DB->GetOne('SELECT MAX(dt) FROM stats');
 $startyear = date('Y',$starttime);
 $endyear = date('Y',$endtime);
 
@@ -76,6 +83,7 @@ $SMARTY->assign('showips',$_POST['showips']);
 $SMARTY->assign('download',$download);
 $SMARTY->assign('upload',$upload);
 $SMARTY->assign('bars',$bars);
+$SMARTY->assign('trafficorder', isset($_SESSION['trafficorder']) ? $_SESSION['trafficorder'] : 'download');
 $SMARTY->display('traffic.html');
 
 ?>
