@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.1 Maybourne
+ * LMS version 1.3.4 Terok
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,11 +21,10 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: userdel.php,v 1.25 2004/02/21 19:38:17 lukasz Exp $
+ *  $Id: userdel.php,v 1.26 2004/03/11 17:24:22 lukasz Exp $
  */
 
 $layout['pagetitle'] = "Usunicie uytkownika ID: ".sprintf("%04d",$_GET['id']);
-$SMARTY->assign('layout',$layout);
 $SMARTY->assign('userid',$_GET['id']);
 
 if (!$LMS->UserExists($_GET['id']))
