@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3-cvs
+ * LMS version 1.3.4 Terok
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,15 +21,15 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: welcome.php,v 1.36 2004/03/12 06:33:44 alec Exp $
+ *  $Id: welcome.php,v 1.37 2004/07/05 23:27:54 lukasz Exp $
  */
 
-require_once($_LIB_DIR."/Sysinfo.class.php");
-require_once($_LIB_DIR."/fortunes.php");
+require_once($_LIB_DIR.'/Sysinfo.class.php');
+require_once($_LIB_DIR.'/fortunes.php');
 
 $SI = new Sysinfo;
 
-$layout['pagetitle'] = "LAN Management System";
+$layout['pagetitle'] = 'LAN Management System';
 
 $layout['dbversion'] = $LMS->DB->GetDBVersion();
 $layout['dbtype'] = $LMS->CONFIG['database']['type'];
